#define PCI_CONFIG_H
#define PCI_ARCH_I386
#define PCI_OS_OPENBSD
#define PCI_HAVE_PM_OBSD_DEVICE
#define PCI_HAVE_PM_MMIO_CONF
#define PCI_HAVE_PM_ECAM
#define PCI_PATH_OBSD_DEVICE "/dev/pci"
#define PCI_PATH_DEVMEM_DEVICE "/dev/mem"
#define PCI_PATH_ACPI_MCFG "/var/db/acpi/MCFG.*"
#define PCI_PATH_EFI_SYSTAB ""
#define PCI_HAVE_PM_INTEL_CONF
#define PCI_HAVE_PM_DUMP
#define PCI_COMPRESSED_IDS
#define PCI_IDS "pci.ids.gz"
#define PCI_PATH_IDS_DIR "/usr/local/share"
#define PCI_USE_DNS
#define PCI_ID_DOMAIN "pci.id.ucw.cz"
#define PCILIB_VERSION "3.15.0"
#define PCILIB_DATE_AMIGAOS "05.04.2026"
